/*
 *  Pedometer - Android App
 *  Copyright (C) 2009 Levente Bagi
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This version of PedometerSettings.java was edited by Shelby Kirn no
 * later than Sunday, April 30, 2017
 */

package com.example.shelby.healthquest40;

import android.content.SharedPreferences;

/**
 * Wrapper for {@link SharedPreferences}, handles preferences-related tasks.
 * @author Levente Bagi
 */
public class PedometerSettings {

    SharedPreferences mSettings;

    public PedometerSettings(SharedPreferences settings) {
        /***********************************************************
         * Establishes that the Pedometer Settings are essentially *
         * Shared Preferences.                                     *
         ***********************************************************/
        mSettings = settings;
    }

    public float getStepLength() {
        /***************************************************************
         * Returns 20 as the step length, and the app is calculated in *
         * imperial, so the step length is 20 inches.                  *
         ***************************************************************/
        /**********************************************************
         * TODO: find a way to have users input their height, and *
         * TODO: calculate the estimated step length accordingly. *
         **********************************************************/
        try {
            return Float.valueOf(mSettings.getString("step_length", "20").trim());
        }
        catch (NumberFormatException e) {
            return 0f; //return 0 inches if we can't find the step length
        }
    }

    //-------------------------------------------------------------------
    // Speaking:

    public boolean wakeAggressively() {
        /**********************************
         * Wakes the phone up from sleep. *
         **********************************/
        return mSettings.getString("operation_level", "run_in_background").equals("wake_up");
    }

    public boolean keepScreenOn() {
        /************************
         * Keeps the screen on. *
         ************************/
        return mSettings.getString("operation_level", "run_in_background").equals("keep_screen_on");
    }
}