/*
 *  Pedometer - Android App
 *  Copyright (C) 2009 Levente Bagi
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This version StepDisplayer.java was edited by Shelby Kirn no later
 * than Wednesday, May 3, 2017.
 */

package com.example.shelby.healthquest40;


import java.util.ArrayList;

/**
 * Counts steps provided by StepDetector and passes the current
 * step count to the activity.
 */
public class StepDisplayer implements StepListener {

    private int mCount = 0;
    PedometerSettings mSettings;

    public StepDisplayer(PedometerSettings settings) {
        /*****************************
         * Initializes StepDisplayer *
         *****************************/
        mSettings = settings;
        notifyListener();
    }

    public void setSteps(int steps) {
        /**********************************************
         * Sets the amount of steps at the beginning. *
         **********************************************/
        mCount = steps;
        notifyListener();
    }

    public void onStep() {
        /*****************************************************
         * If a step is counted, update the step counter and *
         * call the listeners.                               *
         *****************************************************/
        mCount++;
        notifyListener();
    }
    public void passValue() {
        //does nothing
    }

    //-----------------------------------------------------
    // Listener

    public interface Listener {
        /************************************************
         * Initializes the functions that can be called *
         * outside the class.                           *
         ************************************************/
        public void stepsChanged(int value);
        public void passValue();
    }
    private ArrayList<Listener> mListeners = new ArrayList<Listener>();

    public void addListener(Listener l) {
        /********************
         * Adds a listener. *
         ********************/
        mListeners.add(l);
    }
    public void notifyListener() {
        /***************************
         * Notifies the listeners. *
         ***************************/
        for (Listener listener : mListeners) {
            listener.stepsChanged((int)mCount);
        }
    }
}